@@ -22,24 +22,24 @@ pub fn tokenize(input: &str) -> impl Iterator<Item = Token> {
 
 struct TokenIterator<'a> {
     input: &'a str,
-    inline_comment: &'a str,
+    not_parsed_trail: &'a str,
 }
 
 impl<'a> TokenIterator<'a> {
     fn new(input: &'a str) -> Self {
         Self {
             input,
-            inline_comment: "",
+            not_parsed_trail: "",
         }
     }
 
     fn parse_line(&mut self, trail: &'a str, val: &'a str) -> Option<Token<'a>> {
         let parsed_line = line::<'a, VerboseError<&'a str>>(val);
         self.input = trail;
-        if let Ok((comment, token)) = parsed_line {
+        if let Ok((remain, token)) = parsed_line {
             // not parsed trail considered as inline comment
             // and will be parsed later
-            self.inline_comment = comment;
+            self.not_parsed_trail = remain;
             Some(token)
         } else {
             None
@@ -51,12 +51,12 @@ impl<'a> Iterator for TokenIterator<'a> {
     type Item = Token<'a>;
 
     fn next(&mut self) -> Option<Self::Item> {
-        if !self.inline_comment.is_empty() {
-            let parsed_comment = comment::<'a, VerboseError<&'a str>>(self.inline_comment);
-            self.inline_comment = "";
+        if !self.not_parsed_trail.is_empty() {
+            let parsed_comment = comment::<'a, VerboseError<&'a str>>(self.not_parsed_trail);
+            self.not_parsed_trail = "";
             // if there were an error while parsing inline comment (for example it's not started from # or ;)
             // just throw it without stopping parsing
-            // It may be sensible to warn user about it. Should think over about it.
+            // It may be sensible to warn user about it. Should think over it.
             if let Ok((_, inline_comment)) = parsed_comment {
                 return Some(inline_comment);
             }
@@ -104,11 +104,11 @@ fn key_value<'a, E>(input: &'a str) -> IResult<&'a str, Token<'a>, E>
 where
     E: ParseError<&'a str> + std::fmt::Debug,
 {
-    let comment_start_and_separator_chars = "=;#";
+    const COMMENT_START_AND_SEPARATOR_CHARS: &str = "=;#";
     let parser = sequence::separated_pair(
-        is_not(comment_start_and_separator_chars),
+        is_not(COMMENT_START_AND_SEPARATOR_CHARS),
         complete::char('='),
-        is_not(comment_start_and_separator_chars),
+        is_not(COMMENT_START_AND_SEPARATOR_CHARS),
     );
 
     combinator::map(parser, |(k, v): (&str, &str)| {
