@@ -57,6 +57,13 @@ impl<'input> CompareItem<'input> {
     }
 }
 
+#[derive(Debug, PartialEq)]
+pub enum ValidationState {
+    Valid,
+    Invalid,
+    SomeProblems,
+}
+
 pub struct ValidationResult<'input> {
     pub path: &'input str,
     pub duplicate_sections: Vec<&'input str>,
@@ -78,20 +85,40 @@ pub struct Property<'input> {
 }
 
 impl<'input> ValidationResult<'input> {
-    pub fn is_ok(&self) -> bool {
+    pub fn state(&self) -> ValidationState {
+        ValidationState::from(self)
+    }
+
+    fn is_ok(&self) -> bool {
         self.duplicate_properties.is_empty()
             && self.duplicate_sections.is_empty()
             && self.similar_properties.is_empty()
             && self.ext_problems.is_empty()
     }
 
-    pub fn is_invalid(&self) -> bool {
+    fn is_invalid(&self) -> bool {
         !self.duplicate_properties.is_empty()
             || !self.duplicate_sections.is_empty()
             || self.ext_problems.iter().any(|e| !e.duplicates.is_empty())
     }
 }
 
+impl ValidationState {
+    pub fn is_ok(&self) -> bool {
+        matches!(self, ValidationState::Valid)
+    }
+
+    fn from(result: &ValidationResult) -> ValidationState {
+        if result.is_ok() {
+            ValidationState::Valid
+        } else if result.is_invalid() {
+            ValidationState::Invalid
+        } else {
+            ValidationState::SomeProblems
+        }
+    }
+}
+
 pub trait ValidationFormatter {
     fn format(&self, result: ValidationResult);
 }
@@ -128,7 +155,7 @@ pub fn validate_one<V: ValidationFormatter, E: Errorer>(path: &str, formatter: &
     }
 }
 
-pub fn compare<E: Errorer, F: ComparisonFormatter>(
+pub fn compare_files<E: Errorer, F: ComparisonFormatter>(
     path1: &str,
     path2: &str,
     err: &E,
@@ -136,7 +163,7 @@ pub fn compare<E: Errorer, F: ComparisonFormatter>(
 ) {
     if let Some(c1) = read_from_file(path1, err) {
         if let Some(c2) = read_from_file(path2, err) {
-            compare_files(&c1, &c2, formatter);
+            compare(&c1, &c2, formatter);
         }
     }
 }
@@ -157,27 +184,22 @@ fn read_file_content<P: AsRef<Path>>(filename: P) -> Result<String, std::io::Err
     let file = File::open(filename)?;
     let mut reader = BufReader::new(file);
 
-    let mut with_bom = false;
     // Check if file starts with a BOM marker
     // UTF-8: EF BB BF
     let mut bom = [0u8; 3];
     if let Ok(..) = reader.read_exact(&mut bom) {
-        if &bom == b"\xEF\xBB\xBF" {
-            with_bom = true;
+        if &bom != b"\xEF\xBB\xBF" {
+            // Reset file pointer
+            reader.seek(SeekFrom::Start(0))?;
         }
     }
 
-    if !with_bom {
-        // Reset file pointer
-        reader.seek(SeekFrom::Start(0))?;
-    }
-
     let mut contents = String::new();
     reader.read_to_string(&mut contents)?;
     Ok(contents)
 }
 
-fn validate<V: ValidationFormatter>(content: &str, path: &str, formatter: &V) {
+pub fn validate<V: ValidationFormatter>(content: &str, path: &str, formatter: &V) {
     let mut dup_props = BTreeMap::new();
     let mut sim_props = BTreeMap::new();
     let mut all_ext_props = BTreeMap::new();
@@ -250,8 +272,9 @@ fn validate_extension<'a>(ext: String, props: Vec<&'a Property>) -> ExtValidatio
     let similar = similar::find_suffix_pairs(&props)
         .into_iter()
         .filter(|(first, second)| {
-            let first_sections = props_sections.get(first).unwrap();
-            let second_sections = props_sections.get(second).unwrap();
+            let empty = BTreeSet::new();
+            let first_sections = props_sections.get(first).unwrap_or(&empty);
+            let second_sections = props_sections.get(second).unwrap_or(&empty);
             first_sections.intersection(second_sections).count() == 0
         })
         .collect();
@@ -263,7 +286,7 @@ fn validate_extension<'a>(ext: String, props: Vec<&'a Property>) -> ExtValidatio
     }
 }
 
-fn compare_files<F: ComparisonFormatter>(content1: &str, content2: &str, formatter: &F) {
+pub fn compare<F: ComparisonFormatter>(content1: &str, content2: &str, formatter: &F) {
     let empty = BTreeMap::<&str, &str>::new();
 
     let f1 = editorconfig_parser::parse(content1);
@@ -329,6 +352,7 @@ fn map_sections<'a>(sections: &'a [Section<'a>]) -> HashMap<&'a str, BTreeMap<&'
 #[cfg(test)]
 mod tests {
     use super::*;
+    use rstest::*;
     use spectral::prelude::*;
 
     struct TestFormatter<F>
@@ -392,13 +416,45 @@ c = d
 
 [*.md]
 e = f"###;
-        let formatter =
-            TestFormatter::new(|result: ValidationResult| assert_that(&result.is_ok()).is_true());
+        let formatter = TestFormatter::new(|result: ValidationResult| {
+            assert_that!(result.is_ok()).is_true();
+            assert_that(&result.state()).is_equal_to(ValidationState::Valid);
+        });
 
         // Act
         validate(config, "", &formatter);
     }
 
+    #[rstest]
+    #[case(
+        "S=\u{1b}\u{1b}\u{1e}_=\u{1b}\n\u{1b},\u{1b}s=\u{1b}\u{0}\u{0}\u{1b}\u{1b}1L",
+        "\n*\u{1b}\u{1b}",
+        false
+    )]
+    #[trace]
+    fn validate_arbitrary(#[case] content: &str, #[case] path: &str, #[case] expected: bool) {
+        // Arrange
+        let formatter = TestFormatter::new(|result: ValidationResult| {
+            assert_that!(result.is_ok()).is_equal_to(expected);
+            assert_that(&result.state()).is_equal_to(ValidationState::SomeProblems);
+        });
+
+        // Act
+        validate(content, path, &formatter);
+    }
+
+    #[rstest]
+    #[case(ValidationState::Valid, true)]
+    #[case(ValidationState::Invalid, false)]
+    #[case(ValidationState::SomeProblems, false)]
+    #[trace]
+    fn is_ok_tests(#[case] state: ValidationState, #[case] expected: bool) {
+        // Arrange
+
+        // Act
+        assert_that!(state.is_ok()).is_equal_to(expected);
+    }
+
     #[test]
     fn validate_success_brackets_in_section_name() {
         // Arrange
@@ -407,8 +463,10 @@ e = f"###;
 a = b
 c = d
 "###;
-        let formatter =
-            TestFormatter::new(|result: ValidationResult| assert_that(&result.is_ok()).is_true());
+        let formatter = TestFormatter::new(|result: ValidationResult| {
+            assert_that!(result.is_ok()).is_true();
+            assert_that(&result.state()).is_equal_to(ValidationState::Valid);
+        });
 
         // Act
         validate(config, "", &formatter);
@@ -422,8 +480,10 @@ c = d
 a = b # comment 1
 c = d # comment 2
 "###;
-        let formatter =
-            TestFormatter::new(|result: ValidationResult| assert_that(&result.is_ok()).is_true());
+        let formatter = TestFormatter::new(|result: ValidationResult| {
+            assert_that!(result.is_ok()).is_true();
+            assert_that(&result.state()).is_equal_to(ValidationState::Valid);
+        });
 
         // Act
         validate(config, "", &formatter);
@@ -445,6 +505,7 @@ e = f"###;
             assert_that(&result.duplicate_properties.is_empty()).is_false();
             assert_that(&result.duplicate_sections.is_empty()).is_true();
             assert_that(&result.similar_properties.is_empty()).is_true();
+            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
         });
 
         // Act
@@ -468,6 +529,7 @@ e = f"###;
             assert!(result.duplicate_sections.is_empty());
             assert!(!result.similar_properties.is_empty());
             assert_that!(result.ext_problems).is_empty();
+            assert_that(&result.state()).is_equal_to(ValidationState::SomeProblems);
         });
 
         // Act
@@ -492,6 +554,7 @@ e = f"###;
             assert!(result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
             assert_that!(result.ext_problems).is_empty();
+            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
         });
 
         // Act
@@ -514,6 +577,7 @@ a = d
             assert!(result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
             assert_that!(result.ext_problems).has_length(1);
+            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
         });
 
         // Act
@@ -536,6 +600,7 @@ d_a_b_c = d
             assert!(result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
             assert_that!(result.ext_problems).has_length(1);
+            assert_that(&result.state()).is_equal_to(ValidationState::SomeProblems);
         });
 
         // Act
@@ -558,6 +623,7 @@ e = f"###;
             assert!(result.duplicate_properties.is_empty());
             assert!(!result.duplicate_sections.is_empty());
             assert!(result.similar_properties.is_empty());
+            assert_that(&result.state()).is_equal_to(ValidationState::Invalid);
         });
 
         // Act
@@ -584,7 +650,7 @@ c = d2
         });
 
         // Act
-        compare_files(config1, config2, &formatter);
+        compare(config1, config2, &formatter);
     }
 
     #[test]
@@ -614,7 +680,7 @@ c = d2
         });
 
         // Act
-        compare_files(config1, config2, &formatter);
+        compare(config1, config2, &formatter);
     }
 
     #[test]
@@ -636,7 +702,7 @@ d = d2
         });
 
         // Act
-        compare_files(config1, config2, &formatter);
+        compare(config1, config2, &formatter);
     }
 
     #[test]
@@ -659,6 +725,6 @@ d = d2
         });
 
         // Act
-        compare_files(config1, config2, &formatter);
+        compare(config1, config2, &formatter);
     }
 }
